@@ -220,6 +220,10 @@ class ftpretty(object):
         """ Rename a file on the server """
         return self.conn.rename(remote_from, remote_to)
 
+    def mkdir(self, new_dir):
+        """ Create directory on the server """
+        return self.conn.mkd(new_dir)
+
     def close(self):
         """ End the session """
         try:
@@ -232,11 +236,22 @@ class ftpretty(object):
         self.tmp_output.append(line)
 
 
+def _get_year(date):
+    from dateutil.relativedelta import relativedelta
+
+    current_date = datetime.datetime.now()
+    parsed_date = parser.parse("%s" % date)
+    if current_date > parsed_date:
+        current = current_date
+    else:
+        current = current_date - relativedelta(years=1)
+    return current.strftime('%Y')
+
+   
 def split_file_info(fileinfo):
     """ Parse sane directory output usually ls -l
         Adapted from https://gist.github.com/tobiasoberrauch/2942716
     """
-    current_year = datetime.datetime.now().strftime('%Y')
     files = []
 
     unix_format = re.compile(
@@ -267,7 +282,7 @@ def split_file_info(fileinfo):
 
             date = parts[7]
             time = parts[8] if ':' in parts[8] else '00:00'
-            year = parts[8] if ':' not in parts[8] else current_year
+            year = parts[8] if ':' not in parts[8] else _get_year(date)
             dt_obj = parser.parse("%s %s %s" % (date, year, time))
 
             files.append({
@@ -289,6 +304,7 @@ def split_file_info(fileinfo):
 
             hour = int(parts[4])
             hour += 12 if parts[6] == 'P' else 0
+            hour = 0 if hour == 24 else hour
             year = int(parts[3]) + 2000
             dt_obj = datetime.datetime(year, int(parts[1]), int(parts[2]), hour, int(parts[5]), 0)
 
